package docnt_folderTree.json

import groovy.json.JsonBuilder
import org.apache.taglibs.standard.functions.Functions
import org.jahia.services.content.JCRContentUtils
import org.jahia.services.content.JCRNodeWrapper
import org.jahia.taglibs.jcr.node.JCRTagUtils
import org.jahia.utils.WebUtils

JCRNodeWrapper docspaceRootNode = renderContext.mainResource.getNode().getSession().getNodeByIdentifier(renderContext.request.getParameter("docspaceRootNode"));
JCRNodeWrapper selectedFolder = renderContext.mainResource.getNode().getSession().getNodeByIdentifier(renderContext.request.getParameter("currentFolderIdentifier"));

class Folder {
    def id
    def text
    def path
    def state
    def children
}

def listOfNodeToPath = []
listOfNodeToPath.add(docspaceRootNode.identifier)
if (docspaceRootNode.identifier != selectedFolder.identifier) {
    def docspacePath = JCRTagUtils.getMeAndParentsOfType(selectedFolder, 'docmix:docspaceFolder')
    for (def i = 0 ; i < docspacePath.size() ; i++) {
        listOfNodeToPath.add(docspacePath.get(i).identifier)
    }
}

def docspaceRootNodeHasChild = (JCRContentUtils.getChildrenOfType(docspaceRootNode, "docmix:docspaceFolder").size().equals(0))?false:true
def docspaceRootNodeJson = new JsonBuilder()
if (docspaceRootNodeHasChild) {
    def currentFolder = selectedFolder
    def currentFolderMap = new Folder()
    def previousParentIdentifier = ""
    def i = 0;
    while (currentFolder.identifier != docspaceRootNode.identifier ) {
        def childrenList = []
        def childrens = JCRContentUtils.getChildrenOfType(currentFolder, "docmix:docspaceFolder")
        childrens.each { child ->
            if (child.identifier != previousParentIdentifier) {
                def hasChild = (JCRContentUtils.getChildrenOfType(child, "docmix:docspaceFolder").size().equals(0))?false:true
                def isSelected = selectedFolder.identifier == child.identifier
                def childObj = new Folder (
                    id: child.identifier,
                    text: Functions.escapeXml(child.displayableName),
                    path: WebUtils.escapePath(child.path),
                    children: hasChild,
                    state: {
                        opened listOfNodeToPath.contains(child.identifier)
                        selected isSelected
                    }
                )
                childrenList.add(childObj)
            }
        }

        if (previousParentIdentifier != "") {
            childrenList.add(currentFolderMap)
        }

        def isSelected = selectedFolder.identifier == currentFolder.identifier
        currentFolderMap = new Folder (
            id: currentFolder.identifier,
            text: Functions.escapeXml(currentFolder.displayableName),
            path: WebUtils.escapePath(currentFolder.path),
            state: {
                opened listOfNodeToPath.contains(currentFolder.identifier)
                selected isSelected
            },
            children: childrenList
        )

        previousParentIdentifier = currentFolder.identifier
        currentFolder = currentFolder.getParent()
        i++
    }

    def childrenList = []
    def childrens = JCRContentUtils.getChildrenOfType(currentFolder, "docmix:docspaceFolder")
    childrens.each { child ->
        if (child.identifier != previousParentIdentifier) {
            def hasChild = (JCRContentUtils.getChildrenOfType(child, "docmix:docspaceFolder").size().equals(0))?false:true
            def isSelected = selectedFolder.identifier == child.identifier
            def childObj = new Folder (
                id: child.identifier,
                text: Functions.escapeXml(child.displayableName),
                path: WebUtils.escapePath(child.path),
                children: hasChild,
                state: {
                    opened listOfNodeToPath.contains(child.identifier)
                    selected isSelected
                }
            )
            childrenList.add(childObj)
        }
    }

    if (previousParentIdentifier != "") {
        childrenList.add(currentFolderMap)
    }

    def isSelected = selectedFolder.identifier == currentFolder.identifier
    docspaceRootNodeJson {
        id currentFolder.identifier
        text Functions.escapeXml(currentFolder.displayableName)
        path WebUtils.escapePath(currentFolder.path)
        state {
            opened listOfNodeToPath.contains(currentFolder.identifier)
            selected isSelected
        }
        children childrenList
    }
} else {
    docspaceRootNodeJson {
        id docspaceRootNode.identifier
        text Functions.escapeXml(docspaceRootNode.displayableName)
        path WebUtils.escapePath(docspaceRootNode.path)
        children docspaceRootNodeHasChild
        state {
            opened true
            selected true
        }
    }
}
println(docspaceRootNodeJson.toPrettyString())
