package jnt_folder.json

import groovy.json.JsonBuilder
import groovy.json.StringEscapeUtils
import org.apache.commons.lang.WordUtils
import org.apache.taglibs.standard.functions.Functions
import org.jahia.services.content.JCRContentUtils
import org.jahia.services.content.decorator.JCRFileNode
import org.jahia.services.search.FileHit
import org.jahia.utils.FileUtils
import org.jahia.utils.WebUtils
import org.jahia.utils.i18n.Messages

def searchParamSet = false;
def childrens;

def params = ["src_terms[0].term", "src_createdBy", "src_lastModifiedBy", "src_fileType", "createdOnSelected",
              "src_created.from", "src_lastModified.from", "languageSelected"];

params.eachWithIndex { item, index ->
    if (renderContext.request.parameterMap[item] != null && renderContext.request.parameterMap[item][0] != "") {
        searchParamSet = true
    }
}

if(searchParamSet){
    childrens =  moduleMap.resultsHits;
} else if(moduleMap.currentList != null){
    childrens = moduleMap.currentList;
} else {
    childrens = JCRContentUtils.getChildrenOfType(renderContext.mainResource.node, "docmix:docspaceDocument,docmix:docspaceFolder")
}

def jsonBuilder = new JsonBuilder()
def list = []
childrens.eachWithIndex { child, idx ->
    if(child instanceof FileHit) {
        child = child.rawHit;
    }
    def officeURL = ""
    if (org.jahia.modules.docspace.taglibs.Functions.isOfficeDocument((JCRFileNode) child) && org.jahia.modules.docspace.taglibs.Functions.isUserOSWindows(renderContext.request.getHeader("User-Agent"))) {
        officeURL = org.jahia.modules.docspace.taglibs.Functions.getOpenInMSOfficeURL((JCRFileNode) child, url, renderContext)
    }
    def fileCheckboxClass="fileCheckbox"
    if(child.hasPermission("jcr:modifyProperties_default") && child.isLocked()){
        fileCheckboxClass += " restricted"
    }
    if(child.isNodeType("jnt:folder")){
        fileCheckboxClass += " folder"
    }
    if(child.isLocked()){
        fileCheckboxClass += " locked"
    }

    def element = []
    element.add([
        identifier: child.identifier,
        path: WebUtils.escapePath(child.path),
        fullName: Functions.escapeXml(StringEscapeUtils.escapeJavaScript(child.unescapedName)),
        css: fileCheckboxClass
    ])
    element.add((child.isNodeType("jnt:folder")?"folder":FileUtils.getFileIcon(child.name)))
    def documentStatus = (child.hasProperty("documentStatus"))?child.getProperty("documentStatus").string:""
    element.add([
        folder: child.isNodeType("docmix:docspaceFolder"),
        displayName: Functions.escapeXml(WordUtils.abbreviate(child.displayableName, 30, 40, "...")),
        fullName: child.unescapedName,
        locked: child.locked,
        archived: documentStatus,
        path: WebUtils.escapePath(child.path)
    ])
    element.add([
            //Already escaped
        download: (child.isNodeType("nt:folder"))?"":child.getUrl(),
        officeURL: officeURL
    ])
    element.add(child.getProperty("jcr:created").string)
    element.add(child.getProperty("jcr:lastModified").string )
    element.add(child.getProperty("jcr:createdBy").string)
    element.add((child.hasProperty("documentStatus"))?Messages.get("resources.workspace-factory", "docmix_docspaceDocument.documentStatus." + documentStatus, renderContext.mainResourceLocale):"")

    list.add(element)
}
jsonBuilder(data: list)
println(jsonBuilder.toPrettyString())