package jnt_socialActivitiesDisplay.html

import org.jahia.services.SpringContextSingleton
import org.jahia.services.content.JCRNodeWrapper
import org.jahia.taglibs.uicomponents.Functions
import org.joda.time.DateTime
import org.joda.time.Days

import java.text.SimpleDateFormat
import javax.jcr.RepositoryException

/**
 * @author rincevent
 */

def socialService = SpringContextSingleton.getBean("socialService");
def boundComp = Functions.getBoundComponent(currentNode, renderContext, "j:bindedComponent");
def activities;
try {
    limit = currentNode.getProperty("j:activitiesLimit").getLong()
} catch (RepositoryException e) {
    limit = -1L;
}
def activityTypesList = [];
try {
    activityTypesValues = currentNode.getProperty("j:activityTypes").getValues();
    activityTypesValues.each {activityType -> activityTypesList.add(activityType.string)}
} catch (RepositoryException e) {
}
if (boundComp.isNodeType("jnt:user")) {
    def connectionsPaths = socialService.getUserConnections(boundComp.getPath(), true);

    activities = socialService.getActivities(currentNode.session, connectionsPaths, limit, 0, null, activityTypesList);
} else {
    activities = socialService.getActivities(currentNode.session, null, limit, 0, boundComp.getPath(), activityTypesList, binding.variables.containsKey('previousMonths')? new DateTime(System.currentTimeMillis()).minusMonths(new Integer(previousMonths)).millis:0);
}

Comparator<? super JCRNodeWrapper> LOCAL_ACTIVITIES_COMPARATOR = new Comparator<JCRNodeWrapper>() {

    public int compare(JCRNodeWrapper activityNode1, JCRNodeWrapper activityNode2) {
        try {
            // we invert the order to sort with most recent dates on top.
            return activityNode2.getProperty("jcr:lastModified").getDate().compareTo(activityNode1.getProperty("jcr:lastModified").getDate());
        } catch (RepositoryException e) {
            logger.error("Error while comparing creation date on two activities, returning them as equal", e);
            return 0;
        }
    }

};

SortedSet<JCRNodeWrapper> activitiesSet = new TreeSet<JCRNodeWrapper>(LOCAL_ACTIVITIES_COMPARATOR);
activitiesSet.addAll(activities);
def dateFormat = new SimpleDateFormat("yyyy-MM-dd");
def datas = new TreeMap();
def minDate;
def maxDate;
def startDate = binding.variables.containsKey('previousMonths')? new DateTime(System.currentTimeMillis()).minusMonths(new Integer(previousMonths)).millis:0;
activitiesSet.eachWithIndex { activity, index ->
    try {
        def lastModifiedDate = activity.getProperty("jcr:lastModified").getDate().getTime();
        def lastModifiedString = dateFormat.format(lastModifiedDate);
        if (index == 0) {
            minDate = lastModifiedDate;
            maxDate = lastModifiedDate;
        }
        if(lastModifiedDate.time>startDate) {
            if (lastModifiedDate.time < minDate.time) {
                minDate = lastModifiedDate;
            }
            if (lastModifiedDate.time > maxDate.time) {
                maxDate = lastModifiedDate;
            }
            def activityType = "";
            if (datas.get(activityType) == null) {
                datas.put(activityType, new TreeMap());
            }
            def count = 0;
            if (datas.get(activityType).get(lastModifiedString) != null) {
                count = datas.get(activityType).get(lastModifiedString)
            }
            datas.get(activityType).put(lastModifiedString, count + 1);
        }
    } catch (RepositoryException e) {
        limit = 0L;
    }
}

Days days = Days.daysBetween(new DateTime(minDate), new DateTime(maxDate));

if (days.getDays() < 7) {
    datas.each { nbActByDate ->
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(maxDate);
        calendar.add(Calendar.DAY_OF_YEAR, 2);
        for (int i = 0; i < 9; i++) {
            calendar.add(Calendar.DAY_OF_YEAR, -1);
            if (!nbActByDate.value.containsKey(dateFormat.format(calendar.getTime()))) {
                nbActByDate.value.put(dateFormat.format(calendar.getTime()), 0);
            }
        }
    }

} else if (days.getDays() < 31) {
    datas.each { nbActByDate ->
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(maxDate);
        calendar.add(Calendar.DAY_OF_YEAR, 2);
        for (int i = 0; i < 33; i++) {
            calendar.add(Calendar.DAY_OF_YEAR, -1);
            if (!nbActByDate.value.containsKey(dateFormat.format(calendar.getTime()))) {
                nbActByDate.value.put(dateFormat.format(calendar.getTime()), 0);
            }
        }
    }
} else {
    renderContext.getRequest().setAttribute("weeksMap", Boolean.TRUE);
    def tmpdatas = new TreeMap();
    tmpdatas.put("", new TreeMap());
    datas.each { nbActByDate ->
        nbActByDate.value.each { entry ->
            Calendar c = Calendar.getInstance();
            c.setTime(dateFormat.parse(entry.key));
            c.set(Calendar.DAY_OF_WEEK,1); // 1 for week starting on sunday, 2 for monday
            date = dateFormat.format(c.getTime())
            if (!tmpdatas.get(nbActByDate.key).containsKey(date)) {
                tmpdatas.get(nbActByDate.key).put(date, entry.value);
            } else {
                tmpdatas.get(nbActByDate.key).put(date, entry.value + tmpdatas.get(nbActByDate.key).get(date));
            }
        }
    }
    datas = tmpdatas;

    datas.each { nbActByDate ->
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(maxDate);
        calendar.set(Calendar.DAY_OF_WEEK,1);
        calendar.add(Calendar.WEEK_OF_YEAR, 2);
        for (int i = 0; i < 55; i++) {
            calendar.add(Calendar.WEEK_OF_YEAR, -1);
            if (!nbActByDate.value.containsKey(dateFormat.format(calendar.getTime()))) {
                nbActByDate.value.put(dateFormat.format(calendar.getTime()), 0);
            }
        }
    }
}

renderContext.getRequest().setAttribute("socactData",datas);
