<%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
<%@ taglib prefix="jcr" uri="http://www.jahia.org/tags/jcr" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib prefix="template" uri="http://www.jahia.org/tags/templateLib" %>
<%@ taglib prefix="uiComponents" uri="http://www.jahia.org/tags/uiComponentsLib" %>
<%@ taglib prefix="query" uri="http://www.jahia.org/tags/queryLib" %>
<%@ taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<%@ taglib prefix="functions" uri="http://www.jahia.org/tags/functions" %>
<%@ taglib prefix="user" uri="http://www.jahia.org/tags/user" %>

<template:addResources type="css" resources="vendor/typeahead/typeahead.css"/>
<template:addResources type="css" resources="workspace.css"/>

<template:addResources type="javascript" resources="jquery.min.js"/>
<template:addResources type="javascript" resources="jquery-ui.min.js"/>
<template:addResources type="javascript" resources="vendor/typeahead/typeahead.js"/>

<c:set var="bindedComponent"
       value="${uiComponents:getBindedComponent(currentNode, renderContext, 'j:bindedComponent')}"/>

<jcr:nodeProperty node="${currentNode}" name="rolesList" var="rolesList"/>
<jcr:nodeProperty node="${currentNode}" name="defaultRole" var="defaultRoleProp"/>
<c:set var="providedDefaultRole" value="${not empty defaultRoleProp ? defaultRoleProp.string : ''}"/>
<c:forEach items="${rolesList}" var="role" varStatus="status">
    <c:set var="roleName" value="${role.string}"/>
    <c:set var="roles" value="${roles} ${roleName}"/>
    <c:if test="${status.index>0}">
        <c:set var="rolesJs" value="${rolesJs},"/>
    </c:if>
    <fmt:message key="wsf.role.${roleName}" var="roleLabel"/>
    <c:set var="rolesJs" value="${rolesJs}'${roleName}':'${roleLabel}'"/>
    <c:if test="${status.index==0}"><c:set var="firstRole" value="${roleName}"/></c:if>
    <c:if test="${providedDefaultRole==roleName}"><c:set var="defaultRole" value="${roleName}"/></c:if>
</c:forEach>
<c:set var="defaultRole" value="${not empty defaultRole ? defaultRole : firstRole}"/>

<div id="rights_${currentNode.identifier}">
    <template:addResources>
        <script type="text/javascript">
            $(document).ready(function () {
                // typeahead
                var skillSelectionTH = new Bloodhound({
                    datumTokenizer: Bloodhound.tokenizers.whitespace(),
                    queryTokenizer: Bloodhound.tokenizers.whitespace,
                    remote: {
                        url: '<c:url value='/modules/api/jcr/v1/default/${currentResource.locale}/query?noLinks'/>',
                        wildcard: '___QUERY',
                        replace: function(url, query) {
                            this.ajax.data = JSON.stringify({
                                limit: 10,
                                queryName : 'workspaceFactorySearchSkill',
                                parameters : [query.toLowerCase() + '%','% ' + query.toLowerCase() + '%']
                            });
                            return url + "#" + query.toLowerCase();
                        },
                        ajax : {
                            type: 'POST',
                            contentType: 'application/json',
                            dataType: 'json',
                            processData:false
                        }
                    },
                    limit: 10
                });

                // Initialize the Bloodhound suggestion engine
                skillSelectionTH.initialize();

                // Instantiate the Typeahead UI
                $('#skillSelection_${currentNode.identifier}').typeahead(null, {
                    source: skillSelectionTH.ttAdapter(),
                    highlight: true,
                    autocomplete: true,
                    displayKey: function(res) {
                        return res.properties.jcr__title.value;
                    }
                });
            });
        </script>
    </template:addResources>
    <div class="row-fluid">
        <div class="span3">
            <form action="" method="get">
                <fieldset>
                    <input type="hidden" name="displayTab" value="skill-search"/>
                    <input type="hidden" name="d" value="true"/>

                    <div class="control-group">
                        <label class="control-label" for="skillSelection_${currentNode.identifier}"><fmt:message key="docnt_skill"/></label>
                        <div class="controls">
                            <div class="scrollable-dropdown-menu">
                                <input id="skillSelection_${currentNode.identifier}" class="typeahead" type="text"
                                       name="ski" maxlength="32" size="16" placeholder="${startSearching}" value="${fn:escapeXml(param.ski)}">
                            </div>
                        </div>
                    </div>

                    <div class="control-group">
                        <label class="control-label" for="searchmemberslevels_${currentNode.identifier}"><fmt:message key="docnt_skill.level"/></label>
                        <div class="controls">
                            <select class="field" name="lev" id="searchmemberslevels_${currentNode.identifier}">
                                <jcr:propertyInitializers var="levels" name="level" nodeType="docnt:skill"/>
                                <option value="any"><fmt:message key="docnt_docspaceSearchForm.any"/></option>
                                <c:forEach items="${levels}" var="level">
                                    <option value="${level.value.string}"<c:if test="${not empty param.lev and param.lev eq level.value.string}">selected="selected"</c:if> >${level.displayName}</option>
                                </c:forEach>
                            </select>
                        </div>
                    </div>

                    <div class="control-group">
                        <div class="controls">
                            <button class="btn btn-primary" type="submit">
                                <fmt:message key="wsf.label.search"/>
                            </button>
                        </div>
                    </div>
                </fieldset>
            </form>
        </div>

        <div class="span9">
            <c:if test="${not empty param.d}">
                <c:if test="${not empty param.ski}">
                    <c:set var="statement" value="select * from [docnt:skill] as skill where (localname(skill) = '${fn:toLowerCase(param.ski)}' or lower(skill.[jcr:title]) like '${fn:toLowerCase(param.ski)}')"/>
                    <c:if test="${not empty param.lev and param.lev != 'any'}">
                        <c:set var="statement" value="${statement} and skill.['level']='${param.lev}'"/>
                    </c:if>
                    <jcr:jqom var="skills" statement="${statement}"/>
                </c:if>
                <c:set var="totalSize" value="${fn:length(skills.nodes)}"/>

                <c:set var="boostrapPagerID" value="membersSkills"/>
                <template:initPager id="${boostrapPagerID}" totalSize="${totalSize}" pageSize="25"/>

                <div class="row-fluid">
                    <div class="span12">
                        <ul class="thumbnails">
                            <c:set var="isEmptyResult" value="true"/>
                            <c:forEach items="${skills.nodes}" var="skill" begin="${moduleMap['begin']}" end="${moduleMap['end']}">
                                <c:set var="isEmptyResult" value="false"/>
                                <c:set var="entry" value="${jcr:getParentOfType(skill, 'jnt:user')}"/>
                                <%@ include file="userEntry.jspf" %>
                            </c:forEach>
                            <c:if test="${isEmptyResult}">
                                <fmt:message key="jnt_usersManagement.docspace.noUserToDisplay"/>
                            </c:if>
                        </ul>
                    </div>
                </div>

                <%@include file="../../includes/bootstrapPager.jspf"%>
            </c:if>
        </div>
    </div>
</div>